@@ -61,6 +61,12 @@ NULL
 #'     and \code{lookupsAsFactors=FALSE}
 #' @param empty logical. If \code{TRUE} returns empty data.frames for each 
 #'     Datasheet. Ignored if \code{summary=TRUE} Default is \code{FALSE}
+#' @param filterColumn character string. The column to filter a Datasheet by. 
+#'     (e.g. "TransitionGroupID"). Note that to use the filterColumn argument,
+#'     you must also specify the filterValue argument. Default is \code{NULL}
+#' @param filterValue character string or integer. The value to filter the 
+#'     filterColumn by. To use the filterValue argument, you must also specify
+#'     the filterColumn argument. Default is \code{NULL}
 #' @param lookupsAsFactors logical. If \code{TRUE} (default) dependencies 
 #'     returned as factors with allowed values (levels). Set \code{FALSE} to speed 
 #'     calculations. Ignored if \code{summary=TRUE}
@@ -105,8 +111,6 @@ NULL
 #' # Get all Datasheet info for the Scenario
 #' myDatasheets <- datasheet(myScenario)
 #' 
-#' # Can get same info using Project and Scenario arguments
-#' myDatasheets <- datasheet(myLibrary, project = 1, scenario = 1)
 #' 
 #' # Return a list of data.frames (1 for each Datasheet)
 #' myDatasheetList <- datasheet(myScenario, summary = FALSE)
@@ -153,19 +157,19 @@ NULL
 #' 
 #' @export
 #' @import RSQLite
-setGeneric("datasheet", function(ssimObject, name = NULL, project = NULL, scenario = NULL, summary = NULL, optional = FALSE, empty = FALSE, lookupsAsFactors = TRUE, sqlStatement = list(select = "SELECT *", groupBy = ""), includeKey = FALSE, forceElements = FALSE, fastQuery = FALSE) standardGeneric("datasheet"))
+setGeneric("datasheet", function(ssimObject, name = NULL, project = NULL, scenario = NULL, summary = NULL, optional = FALSE, empty = FALSE, filterColumn = NULL, filterValue = NULL, lookupsAsFactors = TRUE, sqlStatement = list(select = "SELECT *", groupBy = ""), includeKey = FALSE, forceElements = FALSE, fastQuery = FALSE) standardGeneric("datasheet"))
 
 # Handles case where ssimObject is list of Scenario or Project objects
 #' @rdname datasheet
-setMethod("datasheet", signature(ssimObject = "list"), function(ssimObject, name, project, scenario, summary, optional, empty, lookupsAsFactors, sqlStatement, includeKey, forceElements, fastQuery) {
+setMethod("datasheet", signature(ssimObject = "list"), function(ssimObject, name, project, scenario, summary, optional, empty, filterColumn, filterValue, lookupsAsFactors, sqlStatement, includeKey, forceElements, fastQuery) {
   cScn <- ssimObject[[1]]
   x <- NULL
-  if (class(cScn) == "Scenario") {
+  if (is(cScn, "Scenario")) {
     x <- getIdsFromListOfObjects(ssimObject, expecting = "Scenario", scenario = scenario, project = project)
     scenario <- x$objs
     project <- NULL
   }
-  if (class(cScn) == "Project") {
+  if (is(cScn, "Project")) {
     x <- getIdsFromListOfObjects(ssimObject, expecting = "Project", scenario = scenario, project = project)
     project <- x$objs
     scenario <- NULL
@@ -176,28 +180,29 @@ setMethod("datasheet", signature(ssimObject = "list"), function(ssimObject, name
   }
   # Now have scenario/project ids of same type in same library, and ssimObject is library
   
-  out <- .datasheet(ssimObject, name = name, project = project, scenario = scenario, summary = summary, optional = optional, empty = empty, lookupsAsFactors = lookupsAsFactors, sqlStatement = sqlStatement, includeKey = includeKey, forceElements = forceElements, fastQuery = fastQuery) # Off for v0.1
+  out <- .datasheet(ssimObject, name = name, project = project, scenario = scenario, summary = summary, optional = optional, empty = empty, filterColumn = filterColumn, filterValue = filterValue, lookupsAsFactors = lookupsAsFactors, sqlStatement = sqlStatement, includeKey = includeKey, forceElements = forceElements, fastQuery = fastQuery) # Off for v0.1
   
   return(out)
 })
 
 #' @rdname datasheet
-setMethod("datasheet", signature(ssimObject = "character"), function(ssimObject, name, project, scenario, summary, optional, empty, lookupsAsFactors, sqlStatement, includeKey, fastQuery) {
+setMethod("datasheet", signature(ssimObject = "character"), function(ssimObject, name, project, scenario, summary, optional, empty, filterColumn, filterValue, lookupsAsFactors, sqlStatement, includeKey, fastQuery) {
   return(SyncroSimNotFound(ssimObject))
 })
 
 #' @rdname datasheet
-setMethod("datasheet", signature(ssimObject = "SsimObject"), function(ssimObject, name, project, scenario, summary, optional, empty, lookupsAsFactors, sqlStatement, includeKey, forceElements, fastQuery) {
+setMethod("datasheet", signature(ssimObject = "SsimObject"), function(ssimObject, name, project, scenario, summary, optional, empty, filterColumn, filterValue, lookupsAsFactors, sqlStatement, includeKey, forceElements, fastQuery) {
   temp <- NULL
   ProjectID <- NULL
   ScenarioID <- NULL
   colOne <- NULL
-  parentID <- NULL
+  ParentID <- NULL
   ParentName <- NULL
+  Name <- NULL
   xProjScn <- .getFromXProjScn(ssimObject, project, scenario, returnIds = TRUE, convertObject = FALSE, complainIfMissing = TRUE)
   IDColumns <- c("ScenarioID", "ProjectID")
   
-  if (class(xProjScn) == "SsimLibrary") {
+  if (is(xProjScn, "SsimLibrary")) {
     x <- xProjScn
     pid <- NULL
     sid <- NULL
@@ -206,7 +211,7 @@ setMethod("datasheet", signature(ssimObject = "SsimObject"), function(ssimObject
     pid <- xProjScn$project
     sid <- xProjScn$scenario
     if (!is.null(sid) & is.null(pid)) {
-      pid <- subset(xProjScn$scenarioSet, is.element(scenarioId, sid))$projectId
+      pid <- subset(xProjScn$scenarioSet, is.element(ScenarioID, sid))$ProjectID
     }
   }
   # now have valid pid/sid vectors and x is library.
@@ -354,6 +359,53 @@ setMethod("datasheet", signature(ssimObject = "SsimObject"), function(ssimObject
           stop("Datasheet ", name, " not found in library.")
         }
       }
+      
+      # Check here if filterColumn exists in current datasheet if not null
+      # Also check here if second part of filterColumn is not an int, find corresponding ID int
+      if (!is.null(filterColumn)) {
+        
+        if (is.null(filterValue)) {
+          stop("filterColumn specified without a filterValue.")
+        }
+        
+        # Check if column exists in Datasheet
+        args <- list(list = NULL, columns = NULL, lib = .filepath(x), sheet = name)
+        tt <- command(args, session = session(x))
+        datasheetCols <- .dataframeFromSSim(tt, csv = FALSE)
+        
+        if (!(filterColumn %in% datasheetCols$name)) {
+          filterColumn <- NULL
+        }
+        else if (is.na(suppressWarnings(as.integer(filterValue)))) {
+          if (sheetNames$isOutput){
+            inputDatasheetName <- subset(datasheetCols, name == filterColumn)$formula1
+            
+            if (inputDatasheetName == "N/A") {
+              inputDatasheetName <- name
+            }
+            
+          } else {
+            inputDatasheetName <- name
+          }
+          tempFile <- paste0(.tempfilepath(x), "/", name, ".csv")
+          unlink(tempFile)
+          args <- list(export = NULL, lib = .filepath(x), sheet = inputDatasheetName,
+                       file = tempFile, valsheets = NULL, extfilepaths = NULL,
+                       includepk = NULL, force = NULL)
+          args <- assignPidSid(args, sheetNames, pid, sid)
+          tt <- command(args, session = session(x))
+          inputDatasheet <- read.csv(tempFile, as.is = TRUE, encoding = "UTF-8")
+          newColID <- inputDatasheet[grepl(filterValue, inputDatasheet$Name, fixed=T),][[filterColumn]] ## when to use Name vs Filename???
+          
+          if (length(newColID) == 0) {
+            stop("filterValue not found in filterColumn.")
+          }
+          
+          filterColumn <- paste0(filterColumn, "=", newColID)
+        } else {
+          filterColumn <- paste0(filterColumn, "=", filterValue)
+        }
+      }
     }
     
     rmCols <- c()
@@ -383,6 +435,11 @@ setMethod("datasheet", signature(ssimObject = "SsimObject"), function(ssimObject
       # Basically an output will make keep console FALSE
       useConsole <- (!sheetNames$isOutput)
       
+      # Use console if filterColumn argument is used
+      if (!is.null(filterColumn)){
+        useConsole <- TRUE
+      }
+
       # Policy change - always query output directly from database. It is faster.
       useConsole <- useConsole & ((sqlStatement$select == "SELECT *")) # &(!lookupsAsFactors))
       useConsole <- useConsole & !((sheetNames$scope == "project") & (length(pid) > 1))
@@ -461,6 +518,11 @@ setMethod("datasheet", signature(ssimObject = "SsimObject"), function(ssimObject
             args <- list(export = NULL, lib = .filepath(x), sheet = name, file = tempFile, valsheets = NULL, extfilepaths = NULL, includepk = NULL, force = NULL) # filepath=NULL
           }
           args <- assignPidSid(args, sheetNames, pid, sid)
+          
+          if (!is.null(filterColumn)){
+            args[["filtercol"]] <- filterColumn
+          }
+          
           tt <- command(args, .session(x))
           
           if (!identical(tt, "saved")) {
@@ -635,7 +697,7 @@ setMethod("datasheet", signature(ssimObject = "SsimObject"), function(ssimObject
             if (is.element("ProjectID", names(lookupSheet))) {
               if (identical(pid, NULL) & !identical(sid, NULL)) {
                 allScns <- scenario(x)
-                findPrjs <- allScns$projectId[is.element(allScns$scenarioId, sid)]
+                findPrjs <- allScns$ProjectID[is.element(allScns$ScenarioID, sid)]
               } else {
                 findPrjs <- pid
               }
@@ -667,7 +729,8 @@ setMethod("datasheet", signature(ssimObject = "SsimObject"), function(ssimObject
                 
                 names(lookupMerge) <- c(cRow$name, "lookupName")
                 sheet <- merge(sheet, lookupMerge, all.x = TRUE)
-                sheet[[cRow$name]] <- sheet$lookupName
+                if(!all(is.na(sheet$lookupName)))
+                  sheet[[cRow$name]] <- sheet$lookupName
                 sheet$lookupName <- NULL
               }
             }
@@ -687,7 +750,6 @@ setMethod("datasheet", signature(ssimObject = "SsimObject"), function(ssimObject
           }
         }
       }
-      
       if (lookupsAsFactors && !useConsole && directQuery) {
         DBI::dbDisconnect(con)
       }
@@ -698,16 +760,9 @@ setMethod("datasheet", signature(ssimObject = "SsimObject"), function(ssimObject
         unlink(gsub(name, rmSheets[i], tempFile, fixed = TRUE))
       }
       
-      # TO DO: deal with NA values in sheet
-      # put columns in correct order
-      sheet$colOne <- sheet[, 1]
-      sheet$cOrder <- seq(1, nrow(sheet))
-      if (empty) {
-        sheet <- subset(sheet, is.null(colOne))
-      } else {
-        sheet <- subset(sheet, !is.na(colOne))
-        sheet <- sheet[order(sheet$cOrder), ]
-      }
+      # Remove rows that are all NA
+      sheet <- sheet[rowSums(is.na(sheet)) != ncol(sheet), ]
+      
       sheet <- subset(sheet, select = outNames)
     } else {
       if (!is.null(rmCols)) {
@@ -734,24 +789,23 @@ setMethod("datasheet", signature(ssimObject = "SsimObject"), function(ssimObject
         }
       }
     }
-    
     if (is.element("ScenarioID", names(sheet))) {
       if (length(sid) == 1) {
         sheet$ScenarioID <- NULL
       } else {
         if (nrow(sheet) > 0) {
           allScns <- scenario(x, summary = TRUE)
-          if (!is.element("parentID", names(allScns))) {
-            warning("Missing parentID info from scenario(summary=TRUE).")
-            allScns$parentID <- NA
+          if (!is.element("ParentID", names(allScns))) {
+            warning("Missing ParentID info from scenario(summary=TRUE).")
+            allScns$ParentID <- NA
           }
-          allScns <- subset(allScns, select = c(scenarioId, projectId, name, parentID))
-          allScns$parentID <- suppressWarnings(as.numeric(allScns$parentID))
-          parentNames <- subset(allScns, select = c(scenarioId, name))
-          names(parentNames) <- c("parentID", "ParentName")
+          allScns <- subset(allScns, select = c(ScenarioID, ProjectID, Name, ParentID))
+          allScns$ParentID <- suppressWarnings(as.numeric(allScns$ParentID))
+          parentNames <- subset(allScns, select = c(ScenarioID, Name))
+          names(parentNames) <- c("ParentID", "ParentName")
           allScns <- merge(allScns, parentNames, all.x = TRUE)
           
-          allScns <- subset(allScns, select = c(scenarioId, projectId, name, parentID, ParentName))
+          allScns <- subset(allScns, select = c(ScenarioID, ProjectID, Name, ParentID, ParentName))
           
           names(allScns) <- c("ScenarioID", "ProjectID", "ScenarioName", "ParentID", "ParentName")
           
