@@ -24,15 +24,24 @@ NULL
 #' @param timestep integer, character string, or vector of integer/character string. 
 #'     Timestep(s) to include. If \code{NULL} (default) then all timesteps are 
 #'     included.  If no Timestep column is in the Datasheet, then ignored
+#' @param filterColumn character string. The column to filter a Datasheet by. 
+#'     (e.g. "TransitionGroupID"). Note that to use the filterColumn argument, 
+#'     you must also specify a filterValue. Default is \code{NULL}
+#' @param filterValue character string or integer. The value of the filterColumn
+#'     to filter the Datasheet by. To use the filterValue argument, you must 
+#'     also specify a filterColumn. Default is \code{NULL}
 #' @param subset logical expression indicating Datasheet rows to return. 
 #'     e.g. expression(grepl("Ts0001", Filename, fixed=T)). See subset() for 
 #'     details (optional)
 #' @param forceElements logical. If \code{TRUE} then returns a single raster as a RasterStack; 
 #'     otherwise returns a single raster as a RasterLayer directly. Default is 
 #'     \code{FALSE}
+#' @param pathOnly logical. If \code{TRUE} then returns a list of filepaths to the raster
+#'     files on disk. Default is \code{FALSE}
 #' 
 #' @return 
-#' A RasterLayer, RasterStack or RasterBrick object. See raster package documentation for details.
+#' A RasterLayer, RasterStack or RasterBrick object, or List. See raster package 
+#' documentation for details.
 #' 
 #' @details 
 #' The names of the returned raster stack contain metadata.
@@ -45,7 +54,7 @@ NULL
 #' \code{paste0(<datasheet name>,".Scn",<scenario id>,".It",<iteration>,".Ts",<timestep>)}.
 #' 
 #' @examples
-#' \donttest{
+#' \dontrun{
 #' # Install the helloworldSpatial package from the server
 #' addPackage("helloworldSpatial")
 #' 
@@ -79,12 +88,13 @@ NULL
 #' 
 #' # Extract specific Datasheet rasters using pattern matching
 #' resultDatasheet <- datasheet(resultScenario, name = "IntermediateDatasheet")
-#' head(resultDatasheet)
+#' colnames(resultDatasheet)
+#' outputRasterPaths <- resultDatasheet$OutputRasterFile
 #' resultRaster <- datasheetRaster(resultScenario, 
 #'                   datasheet = "IntermediateDatasheet",
 #'                   column = "OutputRasterFile",
 #'                   subset = expression(grepl("ts20", 
-#'                                              resultDatasheet$OutputRasterFile,
+#'                                              outputRasterPaths,
 #'                                              fixed = TRUE))
 #' )
 #' 
@@ -94,19 +104,48 @@ NULL
 #'                  column = "OutputRasterFile",
 #'                  forceElements = TRUE
 #'                  )
+#'                  
+#' # Filter for only rasters that fit specific criteria
+#' # Load the ST-Sim spatial example library
+#' addPackage("stsim")
+#' 
+#' # Set the file path and name of the new SsimLibrary
+#' myLibraryName <- file.path(tempdir(),"testlib_stsim_datasheet")
+#' 
+#' # Set the SyncroSim Session
+#' mySession <- session()
+#' 
+#' # Create a new SsimLibrary with the example template from ST-Sim
+#' myLibrary <- ssimLibrary(name = myLibraryName,
+#'                          session = mySession, 
+#'                          package = "stsim",
+#'                          template = "spatial-example")
+#'                          
+#' myScenario <- scenario(myLibrary, scenario = 16)
+#' 
+#' # Run Scenario to generate results
+#' resultScenario <- run(myScenario)
+#' 
+#' 
+#' resultRaster <- datasheetRaster(resultScenario,
+#'                  datasheet = "stsim_OutputSpatialState",
+#'                  timestep = 5,
+#'                  iteration = 5,
+#'                  filterColumn = "TransitionTypeID",
+#'                  filterValue = "Fire")
 #' }
 #' 
 #' @export
-setGeneric("datasheetRaster", function(ssimObject, datasheet, column = NULL, scenario = NULL, iteration = NULL, timestep = NULL, subset = NULL, forceElements = FALSE) standardGeneric("datasheetRaster"))
+setGeneric("datasheetRaster", function(ssimObject, datasheet, column = NULL, scenario = NULL, iteration = NULL, timestep = NULL, filterColumn = NULL, filterValue = NULL, subset = NULL, forceElements = FALSE, pathOnly = FALSE) standardGeneric("datasheetRaster"))
 
 #' @rdname datasheetRaster
-setMethod("datasheetRaster", signature(ssimObject = "character"), function(ssimObject, datasheet, column, scenario, iteration, timestep, subset, forceElements) {
+setMethod("datasheetRaster", signature(ssimObject = "character"), function(ssimObject, datasheet, column, scenario, iteration, timestep, filterColumn, filterValue, subset, forceElements, pathOnly) {
   return(SyncroSimNotFound(ssimObject))
 })
 
 #' @rdname datasheetRaster
-setMethod("datasheetRaster", signature(ssimObject = "list"), function(ssimObject, datasheet, column, scenario, iteration, timestep, subset, forceElements) {
-  if (class(ssimObject[[1]]) != "Scenario") {
+setMethod("datasheetRaster", signature(ssimObject = "list"), function(ssimObject, datasheet, column, scenario, iteration, timestep, filterColumn, filterValue, subset, forceElements, pathOnly) {
+  if (!is(ssimObject[[1]], "Scenario")) {
     stop("Expecting an SsimLibrary/Project/Scenario or list of Scenario objects.")
   }
   if (!is.null(scenario)) {
@@ -116,8 +155,8 @@ setMethod("datasheetRaster", signature(ssimObject = "list"), function(ssimObject
   started <- FALSE
   for (i in 1:length(ssimObject)) {
     cScn <- ssimObject[[i]]
-    cOut <- datasheetRaster(cScn, datasheet = datasheet, column = column, scenario = scenario, iteration = iteration, timestep = timestep, subset = subset, forceElements = forceElements)
-    if (!((class(cOut) == "list") && (length(cOut) == 0))) {
+    cOut <- datasheetRaster(cScn, datasheet = datasheet, column = column, scenario = scenario, iteration = iteration, timestep = timestep, filterColumn = filterColumn, filterValue = filterValue, subset = subset, forceElements = forceElements, pathOnly = pathOnly)
+    if (!(is(cOut, "list") && (length(cOut) == 0))) {
       names(cOut) <- paste0("scn", .scenarioId(cScn), ".", names(cOut))
       if (!started) {
         out <- cOut
@@ -135,17 +174,17 @@ setMethod("datasheetRaster", signature(ssimObject = "list"), function(ssimObject
 })
 
 #' @rdname datasheetRaster
-setMethod("datasheetRaster", signature(ssimObject = "SsimObject"), function(ssimObject, datasheet, column, scenario, iteration, timestep, subset, forceElements) {
+setMethod("datasheetRaster", signature(ssimObject = "SsimObject"), function(ssimObject, datasheet, column, scenario, iteration, timestep, filterColumn, filterValue, subset, forceElements, pathOnly) {
   if (is.null(scenario)) {
     stop("If ssimObject is an SimLibrary or Project, one or more scenarios must be specified using the scenario argument.")
   }
   scnSet <- .scenario(ssimObject)
   missingScns <- scenario
   if (is.character(scenario)) {
-    missingScns <- setdiff(scenario, scnSet$name)
+    missingScns <- setdiff(scenario, scnSet$Name)
   }
   if (is.numeric(scenario)) {
-    missingScns <- setdiff(scenario, scnSet$scenarioId)
+    missingScns <- setdiff(scenario, scnSet$ScenarioID)
   }
   if (length(missingScns) > 0) {
     stop("Scenarios not found in ssimObject: ", paste(missingScns, collapse = ","))
@@ -154,11 +193,11 @@ setMethod("datasheetRaster", signature(ssimObject = "SsimObject"), function(ssim
   scnList <- .scenario(ssimObject, scenario = scenario)
   scenario <- NULL
   
-  return(datasheetRaster(scnList, datasheet, column, scenario, iteration, timestep, subset, forceElements))
+  return(datasheetRaster(scnList, datasheet, column, scenario, iteration, timestep, filterColumn, filterValue, subset, forceElements))
 })
 
 #' @rdname datasheetRaster
-setMethod("datasheetRaster", signature(ssimObject = "Scenario"), function(ssimObject, datasheet, column, scenario, iteration, timestep, subset, forceElements) {
+setMethod("datasheetRaster", signature(ssimObject = "Scenario"), function(ssimObject, datasheet, column, scenario, iteration, timestep, filterColumn, filterValue, subset, forceElements, pathOnly) {
   rat <- NULL
   if (is.null(subset)) {
     getFactors <- FALSE
@@ -191,12 +230,14 @@ setMethod("datasheetRaster", signature(ssimObject = "Scenario"), function(ssimOb
   }
   
   # TO DO: make sure datasheet is spatial after opening
-  cMeta <- .datasheet(x, name = datasheet, optional = TRUE, lookupsAsFactors = getFactors)
+  cMeta <- .datasheet(x, name = datasheet, optional = TRUE, filterColumn = filterColumn, filterValue = filterValue, lookupsAsFactors = getFactors)
   
   if (nrow(cMeta) == 0) {
-    cMeta <- .datasheet(x, name = datasheet, optional = TRUE, lookupsAsFactors = getFactors)
+    cMeta <- .datasheet(x, name = datasheet, optional = TRUE, filterColumn = filterColumn, filterValue = filterValue, lookupsAsFactors = getFactors)
   }
-  tt <- command(list(list = NULL, columns = NULL, allprops = NULL, sheet = datasheet, csv = NULL, lib = .filepath(x)), session = .session(x))
+  args <- list(list = NULL, columns = NULL, allprops = NULL, sheet = datasheet, csv = NULL, lib = .filepath(x))
+  
+  tt <- command(args, session = .session(x))
   cPropsAll <- .dataframeFromSSim(tt)
   cPropsAll$isRaster <- grepl("isRaster^True", cPropsAll$properties, fixed = TRUE)
   # get a valid raster column
@@ -244,7 +285,7 @@ setMethod("datasheetRaster", signature(ssimObject = "Scenario"), function(ssimOb
           warning(warningMsg)
         }
       } else {
-        cMeta <- .datasheet(x, name = datasheet, optional = TRUE, lookupsAsFactors = getFactors)
+        cMeta <- .datasheet(x, name = datasheet, optional = TRUE, filterColumn = filterColumn, lookupsAsFactors = getFactors)
       }
     }
     tryCount <- tryCount + 1
@@ -266,44 +307,6 @@ setMethod("datasheetRaster", signature(ssimObject = "Scenario"), function(ssimOb
   
   # Now cMeta contains bandColumn, rasterColumn, and only rows to be exported
   cMeta$outName <- gsub(".tif", "", basename(cMeta$rasterColumn), fixed = TRUE)
-  
-  if (grepl("It0000-Ts0000-", cMeta$outName[1])) {
-    cMeta$outName[1] <- gsub("It0000-Ts0000-", "", cMeta$outName[1], fixed = TRUE)
-    cMeta$outName[1] <- paste0(cMeta$outName, ".it0.ts0")
-  }
-  
-  if (is.element("Iteration", names(cMeta)) && (length(setdiff(cMeta$Iteration, c(NA))) > 0)) {
-    tsReplaceBits <- cMeta$Iteration
-    tsReplaceBits[tsReplaceBits < 10] <- paste0("It000", tsReplaceBits[tsReplaceBits < 10], "-")
-    tsReplaceBits[(10 <= tsReplaceBits) & (tsReplaceBits < 100)] <- paste0("It00", tsReplaceBits[(10 <= tsReplaceBits) & (tsReplaceBits < 100)], "-")
-    tsReplaceBits[(100 <= tsReplaceBits) & (tsReplaceBits < 1000)] <- paste0("It0", tsReplaceBits[(100 <= tsReplaceBits) & (tsReplaceBits < 1000)], "-")
-    tsReplaceBits[(1000 <= tsReplaceBits) & (tsReplaceBits < 10000)] <- paste0("It", tsReplaceBits[(1000 <= tsReplaceBits) & (tsReplaceBits < 10000)], "-")
-    for (i in seq(length.out = length(tsReplaceBits))) {
-      cMeta$outName <- gsub(tsReplaceBits[i], "", cMeta$outName, fixed = TRUE)
-    }
-    for (k in seq(length.out = nrow(cMeta))) {
-      addString <- paste0(".it", cMeta$Iteration[k])
-      if (!grepl(addString, cMeta$outName[k], fixed = TRUE)) {
-        cMeta$outName[k] <- paste0(cMeta$outName[k], addString)
-      }
-    }
-  }
-  if (is.element("Timestep", names(cMeta)) && (length(setdiff(cMeta$Timestep, c(NA))) > 0)) {
-    tsReplaceBits <- cMeta$Timestep
-    tsReplaceBits[tsReplaceBits < 10] <- paste0("Ts000", tsReplaceBits[tsReplaceBits < 10], "-")
-    tsReplaceBits[(10 <= tsReplaceBits) & (tsReplaceBits < 100)] <- paste0("Ts00", tsReplaceBits[(10 <= tsReplaceBits) & (tsReplaceBits < 100)], "-")
-    tsReplaceBits[(100 <= tsReplaceBits) & (tsReplaceBits < 1000)] <- paste0("Ts0", tsReplaceBits[(100 <= tsReplaceBits) & (tsReplaceBits < 1000)], "-")
-    tsReplaceBits[(1000 <= tsReplaceBits) & (tsReplaceBits < 10000)] <- paste0("Ts", tsReplaceBits[(1000 <= tsReplaceBits) & (tsReplaceBits < 10000)], "-")
-    for (i in seq(length.out = length(tsReplaceBits))) {
-      cMeta$outName <- gsub(tsReplaceBits[i], "", cMeta$outName, fixed = TRUE)
-    }
-    for (k in seq(length.out = nrow(cMeta))) {
-      addString <- paste0(".ts", cMeta$Timestep[k])
-      if (!grepl(addString, cMeta$outName[k], fixed = TRUE)) {
-        cMeta$outName[k] <- paste0(cMeta$outName[k], addString)
-      }
-    }
-  }
 
   if ((length(setdiff(NA, unique(cMeta$Band))) > 0) & length(intersect(names(cMeta), c("Timestep", "Iteration"))) == 0) {
     cMeta$outName <- paste0(cMeta$outName, ".b", cMeta$bandColumn)
@@ -379,6 +382,11 @@ setMethod("datasheetRaster", signature(ssimObject = "Scenario"), function(ssimOb
     }
   }
   
+  # If return pathOnly = TRUE, just return filepaths to rasters
+  if (pathOnly) {
+    return(cMeta$rasterColumn)
+  }
+  
   # ensure layers are sorted by name
   sortNames <- sort(names(cStack))
   cStack <- raster::subset(cStack, sortNames)
