@@ -147,13 +147,15 @@ runtimeTempFolder <- function(folderName) {
 #' for a SyncroSim simulation.
 #' 
 #' @param type character. Update to apply to progress bar. Options include
-#' "begin", "end", "step", and "report" (Default is "step")
+#' "begin", "end", "step", "report", and "message" (Default is "step")
 #' @param iteration integer. The current iteration. Only used if 
 #' \code{type = "report"}
 #' @param timestep integer. The current timestep. Only used if 
 #' \code{type = "report"}
 #' @param totalSteps integer. The total number of steps in the simulation. Only
 #' used if \code{type = "begin"}
+#' @param message character. An arbitrary messsage to be printed to the status
+#' bar. Only used if \code{type = "message"}.
 #' 
 #' @return 
 #' No returned value, used for side effects
@@ -169,12 +171,15 @@ runtimeTempFolder <- function(folderName) {
 #' # Report progress for a simulation
 #' progressBar(type = "report", iteration = iter, timestep = ts)
 #' 
+#' # Report arbitrary progress message 
+#' progressBar(type = "message", message = msg)
+#' 
 #' # End the progress bar for a simulation
 #' progressBar(type = "end")
 #' }
 #' 
 #' @export
-progressBar <- function(type = "step", iteration = NULL, timestep = NULL, totalSteps = NULL) {
+progressBar <- function(type = "step", iteration = NULL, timestep = NULL, totalSteps = NULL, message) {
   
   # Check Program Directory
   envValidateEnvironment()
@@ -206,10 +211,64 @@ progressBar <- function(type = "step", iteration = NULL, timestep = NULL, totalS
     } else {
       stop("iteration and timestep arguments must be integers")
     }
+    
+  # Print arbitrary message to UI
+  } else if (type == "message") {
+    if (!missing(message)) {
+      cat(paste0("ssim-task-status=", as.character(message), "\r\n"))
+      flush.console()
+    } else {
+      stop("please provide a message")
+    }
   
   # Throw error if type not specified correctly  
   } else {
     stop("Invalid type argument")
   }
   
-}
\ No newline at end of file
+}
+
+#' Function to write to the SyncroSim run log
+#' 
+#' This function is designed to facilitate the development of R-based Syncrosim 
+#' Packages by allowing developers to send messages to the run log.
+#' 
+#' @param ... One or more objects which can be coerced to character
+#' which are pasted together using `sep`.
+#' @param sep character. Used to separate terms. Not NA_character_
+#' @param type character. Type of message to add to run log. One of "status",
+#' "info", or "warning".
+#' 
+#' @return 
+#' No returned value, used for side effects
+#' 
+#' @examples 
+#' \dontrun{
+#' # Write a message to run log
+#' updateRunLog(msg)
+#' 
+#' # Construct and write a message to run log
+#' updateRunLog(msg, additionalMsg, sep = " ")
+#' }
+#'
+#' @export
+updateRunLog <- function(..., sep = "", type = "status") {
+  if(length(list(...)) == 0)
+    stop("Please provide a message to write to the run log.")
+  
+  if(!type %in% c("status", "info", "warning"))
+    stop("Please select a valid run log message type.")
+  
+  msg <- paste(..., sep = sep, collapse = "")
+  msg <- paste0("ssim-task-log=", strsplit(msg, "\n")[[1]], "\r\n")
+  
+  if(type == "info")
+    msg[1] <- sub("ssim-task-log", "ssim-task-info", msg[1])
+  if(type == "warning")
+    msg[1] <- sub("ssim-task-log", "ssim-task-warning", msg[1])
+   
+  for(m in msg) {
+    cat(m)
+    flush.console()
+  }
+}
